@@ -4,10 +4,11 @@
 # :license:   BSD (3 Clause), see LICENSE for more details.
 
 import re
-
 from collections import namedtuple
 
-__version__ = '2.2.0'
+import django
+
+__version__ = '2.3.1'
 __author__ = 'Asif Saif Uddin, Ask Solem'
 __contact__ = 'auvipy@gmai.com, ask@celeryproject.org'
 __homepage__ = 'https://github.com/celery/django-celery-results'
@@ -30,4 +31,5 @@ del(re)
 
 __all__ = []
 
-default_app_config = 'django_celery_results.apps.CeleryResultConfig'
+if django.VERSION < (3, 2):
+    default_app_config = 'django_celery_results.apps.CeleryResultConfig'
