@@ -4,14 +4,24 @@ import json
 from celery import maybe_signature
 from celery.backends.base import BaseDictBackend
 from celery.exceptions import ChordError
-from celery.result import allow_join_result, result_from_tuple, GroupResult
-from celery.utils.serialization import b64encode, b64decode
+from celery.result import GroupResult, allow_join_result, result_from_tuple
 from celery.utils.log import get_logger
+from celery.utils.serialization import b64decode, b64encode
+from django.db import connection, transaction
+from django.db.utils import InterfaceError
 from kombu.exceptions import DecodeError
-from django.db import transaction
 
-from ..models import TaskResult, ChordCounter, GroupResult as GroupResultModel
+from ..models import ChordCounter
+from ..models import GroupResult as GroupResultModel
+from ..models import TaskResult
 
+EXCEPTIONS_TO_CATCH = (InterfaceError,)
+
+try:
+    from psycopg2 import InterfaceError as Psycopg2InterfaceError
+    EXCEPTIONS_TO_CATCH += (Psycopg2InterfaceError,)
+except ImportError:
+    pass
 
 logger = get_logger(__name__)
 
@@ -23,6 +33,27 @@ class DatabaseBackend(BaseDictBackend):
     GroupModel = GroupResultModel
     subpolling_interval = 0.5
 
+    def exception_safe_to_retry(self, exc):
+        """Check if an exception is safe to retry.
+
+        Backends have to overload this method with correct predicates
+        dealing with their exceptions.
+
+        By default no exception is safe to retry, it's up to
+        backend implementation to define which exceptions are safe.
+
+        For Celery / django-celery-results, retry Django / Psycopg2
+        InterfaceErrors, like "Connection already closed", with new connection.
+
+        Set result_backend_always_retry to True in order to enable retries.
+        """
+        for exc_type in EXCEPTIONS_TO_CATCH:
+            if isinstance(exc, exc_type):
+                # Only called if InterfaceError occurs and always_retry is True
+                connection.close()
+                return True
+        return False
+
     def _store_result(
             self,
             task_id,
@@ -39,6 +70,8 @@ class DatabaseBackend(BaseDictBackend):
         )
 
         task_name = getattr(request, 'task', None)
+        properties = getattr(request, 'properties', {}) or {}
+        periodic_task_name = properties.get('periodic_task_name', None)
         worker = getattr(request, 'hostname', None)
 
         # Get input arguments
@@ -71,6 +104,7 @@ class DatabaseBackend(BaseDictBackend):
             status,
             traceback=traceback,
             meta=meta,
+            periodic_task_name=periodic_task_name,
             task_name=task_name,
             task_args=task_args,
             task_kwargs=task_kwargs,
@@ -224,7 +258,7 @@ def trigger_callback(app, callback, group_result):
     except Exception as exc:  # pylint: disable=broad-except
         try:
             culprit = next(group_result._failed_join_report())
-            reason = "Dependency {0.id} raised {1!r}".format(culprit, exc)
+            reason = f"Dependency {culprit.id} raised {exc!r}"
         except StopIteration:
             reason = repr(exc)
         logger.exception("Chord %r raised: %r", group_result.id, exc)
@@ -235,5 +269,5 @@ def trigger_callback(app, callback, group_result):
         except Exception as exc:  # pylint: disable=broad-except
             logger.exception("Chord %r raised: %r", group_result.id, exc)
             app.backend.chord_error_from_stack(
-                callback, exc=ChordError("Callback error: {0!r}".format(exc))
+                callback, exc=ChordError(f"Callback error: {exc!r}")
             )
