@@ -1,17 +1,14 @@
 """Model managers."""
 
 import warnings
-
 from functools import wraps
 from itertools import count
 
 from celery.utils.time import maybe_timedelta
-
-from django.db import connections, router, transaction
-from django.db import models
 from django.conf import settings
+from django.db import connections, models, router, transaction
 
-from .utils import now
+from .utils import now, raw_delete
 
 W_ISOLATION_REP = """
 Polling results with transaction isolation level 'repeatable-read'
@@ -91,7 +88,7 @@ class ResultManager(models.Manager):
     def delete_expired(self, expires):
         """Delete all expired results."""
         with transaction.atomic():
-            self.get_all_expired(expires).delete()
+            raw_delete(queryset=self.get_all_expired(expires))
 
 
 class TaskResultManager(ResultManager):
@@ -122,6 +119,7 @@ class TaskResultManager(ResultManager):
     def store_result(self, content_type, content_encoding,
                      task_id, result, status,
                      traceback=None, meta=None,
+                     periodic_task_name=None,
                      task_name=None, task_args=None, task_kwargs=None,
                      worker=None, using=None):
         """Store the result and status of a task.
@@ -131,6 +129,7 @@ class TaskResultManager(ResultManager):
             content_type (str): Mime-type of result and meta content.
             content_encoding (str): Type of encoding (e.g. binary/utf-8).
             task_id (str): Id of task.
+            periodic_task_name (str): Celery Periodic task name.
             task_name (str): Celery task name.
             task_args (str): Task arguments.
             task_kwargs (str): Task kwargs.
@@ -160,6 +159,7 @@ class TaskResultManager(ResultManager):
             'meta': meta,
             'content_encoding': content_encoding,
             'content_type': content_type,
+            'periodic_task_name': periodic_task_name,
             'task_name': task_name,
             'task_args': task_args,
             'task_kwargs': task_kwargs,
