@@ -1,14 +1,13 @@
-import mock
-import celery
 import json
-import pytest
-import re
 import pickle
+import re
+from unittest import mock
 
-from celery import uuid
-from celery import states
+import celery
+import pytest
+from celery import states, uuid
 from celery.app.task import Context
-from celery.result import GroupResult, AsyncResult
+from celery.result import AsyncResult, GroupResult
 from celery.utils.serialization import b64decode
 from celery.worker.request import Request
 from celery.worker.strategy import hybrid_to_proto2
@@ -46,7 +45,7 @@ class test_DatabaseBackend:
         )
         if task_protocol == 1:
             body, headers, _, _ = hybrid_to_proto2(msg, msg.body)
-            properties = {}
+            properties = None
             sent_event = {}
         else:
             headers, properties, body, sent_event = msg
@@ -723,6 +722,7 @@ class test_DatabaseBackend:
         request.argsrepr = "argsrepr"
         request.kwargsrepr = "kwargsrepr"
         request.hostname = "celery@ip-0-0-0-0"
+        request.properties = {"periodic_task_name": "my_periodic_task"}
         request.ignore_result = False
         result = {"foo": "baz"}
 
@@ -771,6 +771,7 @@ class test_DatabaseBackend:
         request.argsrepr = "argsrepr"
         request.kwargsrepr = "kwargsrepr"
         request.hostname = "celery@ip-0-0-0-0"
+        request.properties = {"periodic_task_name": "my_periodic_task"}
         request.ignore_result = False
         request.chord.id = cid
         result = {"foo": "baz"}
@@ -816,6 +817,7 @@ class test_DatabaseBackend:
         request.argsrepr = "argsrepr"
         request.kwargsrepr = "kwargsrepr"
         request.hostname = "celery@ip-0-0-0-0"
+        request.properties = {"periodic_task_name": "my_periodic_task"}
         request.chord.id = cid
         result = {"foo": "baz"}
 
